==> flyspray_0.9.6a.orig.tar.gz: flyspray-0.9.6/lang/de/register.php <==
﻿<?php

global $newuser_text;
$register_text = array (

'registernewuser' =>  'Neuen Benutzer registrieren',
'requiredfields'  =>  'Notwendige Felder sind gekennzeichnet:',
'username'        =>  'Benutzername',
'password'        =>  'Passwort',
'confirmpass'     =>  'Passwort bestätigen',
'realname'        =>  'Realname',
'emailaddress'    =>  'E-Mail',
'jabberid'        =>  'Jabber ID',
'notifications'   =>  'Benachrichtigungen',
'none'            =>  'Keine',
'email'           =>  'E-Mail',
'jabber'          =>  'Jabber',
'note'            =>  '<em>Hinweis:</em> Ihnen wird auf dem gewählten Weg ein Bestätigungscode zugesandt, bevor Ihr Konto eröffnet wird. <strong>Wenn Sie falsche Angaben machen, werden Sie den Code nicht erhalten!</strong>',
'sendcode'        =>  'Code senden!',
'entercode'       =>  'Ihr Bestätigungscode wurde versendet. Wenn Sie ihn erhalten haben, geben Sie ihn zusammen mit Ihrem gewünschten Passwort in untenstehendem Formular ein.',
'confirmationcode'=>  'Bestätigungscode',
'registeraccount' =>  'Konto registrieren',
'registererror'   =>  'Stellen Sie sicher, dass Sie alle notwendigen Felder ausgefüllt und korrekte Details zu Ihrer Benachrichtigungsmethode gemacht haben.',
'usernametaken'   =>  'Dieser Benutzername wurde bereits vergeben. Wählen Sie bitte einen anderen Namen.',
'goback'          =>  'Zurück',
'noticefrom'      =>  'Nachricht von',
'addressused'     =>  'Diese Adresse wurde verwendet, um ein Flyspray-Benutzerkonto anzulegen. Wenn Sie diese Nachricht nicht erwartet haben, ignorieren und löschen Sie sie bitte. Ihr Bestätigungscode lautet: '


);
?>

==> flyspray_0.9.7.orig.tar.gz: flyspray-0.9.7/lang/de/register.php <==
<?php

global $newuser_text;
$register_text = array (

'registernewuser' =>  'Neuen Benutzer registrieren',
'requiredfields'  =>  'Notwendige Felder sind gekennzeichnet:',
'username'        =>  'Benutzername',
'password'        =>  'Passwort',
'confirmpass'     =>  'Passwort bestätigen',
'realname'        =>  'Realname',
'emailaddress'    =>  'E-Mail',
'jabberid'        =>  'Jabber ID',
'notifications'   =>  'Benachrichtigungen',
'none'            =>  'Keine',
'email'           =>  'E-Mail',
'jabber'          =>  'Jabber',
'note'            =>  '<em>Hinweis:</em> Ihnen wird auf dem gewählten Weg ein Bestätigungscode zugesandt, bevor Ihr Konto eröffnet wird. <strong>Wenn Sie falsche Angaben machen, werden Sie den Code nicht erhalten!</strong>',
'sendcode'        =>  'Code senden!',
'entercode'       =>  'Ihr Bestätigungscode wurde versendet. Wenn Sie ihn erhalten haben, geben Sie ihn zusammen mit Ihrem gewünschten Passwort in untenstehendem Formular ein.',
'confirmationcode'=>  'Bestätigungscode',
'registeraccount' =>  'Konto registrieren',
'registererror'   =>  'Stellen Sie sicher, dass Sie alle notwendigen Felder ausgefüllt und korrekte Details zu Ihrer Benachrichtigungsmethode gemacht haben.',
'usernametaken'   =>  'Dieser Benutzername wurde bereits vergeben. Wählen Sie bitte einen anderen Namen.',
'goback'          =>  'Zurück',
'noticefrom'      =>  'Nachricht von',
'addressused'     =>  'Diese Adresse wurde verwendet, um ein Flyspray-Benutzerkonto anzulegen. Wenn Sie diese Nachricht nicht erwartet haben, ignorieren und löschen Sie sie bitte. Ihr Bestätigungscode lautet: ',

// Added in version 0.9.7
'badmagic'        =>  'Der Bestätigungscode ist ungültig. Stellen Sie sicher, dass Sie den Code richtig aus der Benachrichtigung kopiert haben.',

);
?>
